==> fdordbms-3.2.2.tar.gz: OpenSource_FDO/Providers/GenericRdbms/Src/MySQL/SchemaMgr/SchemaManager.cpp <==
 //
 // Copyright (C) 2004-2006  Autodesk, Inc.
 // 
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of version 2.1 of the GNU Lesser
 // General Public License as published by the Free Software Foundation.
 // 
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
 // 
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#include "stdafx.h"
#include "SchemaManager.h"
#include "Lp/SchemaCollection.h"
#include "Ph/Mgr.h"

FdoMySqlSchemaManager::FdoMySqlSchemaManager(GdbiConnection* connection, FdoStringP mqlSchemaName) :
    FdoGrdSchemaManager( connection ),
    mMySqlSchemaName(mqlSchemaName)
{
}

FdoMySqlSchemaManager::~FdoMySqlSchemaManager(void)
{
}

FdoSmLpSchemasP FdoMySqlSchemaManager::CreateLogicalPhysicalSchemas(FdoSmPhMgrP physMgr, FdoSmLpSpatialContextsP spatialContexts)
{
    return new FdoSmLpMySqlSchemaCollection(physMgr, spatialContexts);
}

FdoSmPhMgrP FdoMySqlSchemaManager::CreatePhysicalSchema()
{
    return new FdoSmPhMySqlMgr(GetGdbiConnection(), mMySqlSchemaName);
}

void FdoMySqlSchemaManager::ApplySchema( 
    FdoFeatureSchemaP pFeatSchema, 
    FdoPhysicalSchemaMappingP pOverrides,
    bool bIgnoreStates
)
{
    //TODO: This override function bybasses FdoGrdSchemaManager::ApplySchema,
    //which wraps the apply in a transaction. However, currently get 
    //'command out of sequence' errors on MySql. This problem needs to be
    //resolved. When it is, FdoMySqlSchemaManager::ApplySchema() can be removed.
    FdoSchemaManager::ApplySchema( pFeatSchema, pOverrides, bIgnoreStates ); 
}

==> fdordbms-3.3.2.tar.gz: OpenSource_FDO/Providers/GenericRdbms/Src/MySQL/SchemaMgr/SchemaManager.cpp <==
 //
 // Copyright (C) 2004-2006  Autodesk, Inc.
 // 
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of version 2.1 of the GNU Lesser
 // General Public License as published by the Free Software Foundation.
 // 
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
 // 
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#include "stdafx.h"
#include "SchemaManager.h"
#include "Lp/SchemaCollection.h"
#include "Ph/Mgr.h"

FdoMySqlSchemaManager::FdoMySqlSchemaManager(GdbiConnection* connection, FdoStringP mqlSchemaName) :
    FdoGrdSchemaManager( connection ),
    mMySqlSchemaName(mqlSchemaName)
{
}

FdoMySqlSchemaManager::~FdoMySqlSchemaManager(void)
{
}

FdoSmLpSchemasP FdoMySqlSchemaManager::CreateLogicalPhysicalSchemas(FdoSmPhMgrP physMgr, FdoSmLpSpatialContextMgrP scMgr)
{
    return new FdoSmLpMySqlSchemaCollection(physMgr, scMgr);
}

FdoSmPhMgrP FdoMySqlSchemaManager::CreatePhysicalSchema()
{
    return new FdoSmPhMySqlMgr(GetGdbiConnection(), mMySqlSchemaName);
}

void FdoMySqlSchemaManager::ApplySchema( 
    FdoFeatureSchemaP pFeatSchema, 
    FdoPhysicalSchemaMappingP pOverrides,
    bool bIgnoreStates
)
{
    //TODO: This override function bybasses FdoGrdSchemaManager::ApplySchema,
    //which wraps the apply in a transaction. However, currently get 
    //'command out of sequence' errors on MySql. This problem needs to be
    //resolved. When it is, FdoMySqlSchemaManager::ApplySchema() can be removed.
    FdoSchemaManager::ApplySchema( pFeatSchema, pOverrides, bIgnoreStates ); 
}
